## Welcome to LineUsPythonModule!

The LineUsPythonModule is a really simple and easy way to get started with controlling your Line-us from Python. Take a look at the [Quickstart section](https://lineuspythonmodule.readthedocs.io/en/latest/#quickstart) in the documentation to get going.

#### Documentation
Full documentation for the Line-us Python module is available on [ReadTheDocs](https://lineuspythonmodule.readthedocs.io/en/latest/)

#### What is Line-us?
Line-us is an internet connected robot drawing arm. It's small, portable and draws with a nice wobbly line using a real pen on paper. The free app lets you draw, send messages, share sketchbooks or enjoy collecting artworks from others!

Line-us was created in London by Durrell Bishop and Robert Poll. There is a lot more information on our website: https://www.line-us.com

If you have any questions please drop us an email: help@line-us.com of post on our forum: https://forum.line-us.com

Have fun!!
